@@ -5,5 +5,6 @@ var _ogre_g_l_s_l_program_common_8h =
     [ "GLUniformReferenceList", "_ogre_g_l_s_l_program_common_8h.html#ab6bb0d65dc078300d6e0459f926292b4", null ],
     [ "GLUniformReferenceIterator", "_ogre_g_l_s_l_program_common_8h.html#a644f74bf84779c83312a97e169164d07", null ],
     [ "GLUniformBufferList", "_ogre_g_l_s_l_program_common_8h.html#a5746fd100d687fa86400aba8bd1e81da", null ],
-    [ "GLUniformBufferIterator", "_ogre_g_l_s_l_program_common_8h.html#a1930e01c82d79435264363ad4711ec34", null ]
+    [ "GLUniformBufferIterator", "_ogre_g_l_s_l_program_common_8h.html#a1930e01c82d79435264363ad4711ec34", null ],
+    [ "SharedParamsBufferMap", "_ogre_g_l_s_l_program_common_8h.html#a0013629ba7e62b9f0ffb427b0db06059", null ]
 ];
\ No newline at end of file
